<?php
namespace PortalPeople\DisabledDates\Model\ResourceModel\DisabledDate;

use Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection;
use Magento\Framework\Api\Search\SearchResultInterface;
use Magento\Framework\Api\SearchCriteriaInterface;
use Magento\Framework\Api\Search\AggregationInterface;

class Collection extends \Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection implements \Magento\Framework\Api\Search\SearchResultInterface
{
    protected $_idFieldName = 'entity_id';
    protected $aggregations;

    protected function _construct()
    {
        $this->_init(
            \PortalPeople\DisabledDates\Model\DisabledDate::class,
            \PortalPeople\DisabledDates\Model\ResourceModel\DisabledDate::class
        );
    }

    // SearchResultInterface implementation
    public function getSearchCriteria()
    {
        return null;
    }

    public function setSearchCriteria(SearchCriteriaInterface $searchCriteria = null)
    {
        return $this;
    }

    public function getTotalCount()
    {
        return $this->getSize();
    }

    public function setTotalCount($totalCount)
    {
        return $this;
    }

    public function setItems(array $items = null)
    {
        return $this;
    }

    public function getAggregations()
    {
        return $this->aggregations;
    }

    public function setAggregations($aggregations)
    {
        $this->aggregations = $aggregations;
        return $this;
    }
}
