<?php

namespace PortalPeople\DisabledDates\Controller\Adminhtml\Index;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;

class Index extends Action
{
    protected $resultPageFactory;

    public function __construct(
        Context $context,
        PageFactory $resultPageFactory
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
    }

    public function execute()
    {
        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('PortalPeople_DisabledDates::disabled_dates');
        $resultPage->getConfig()->getTitle()->prepend(__('Disabled Dates'));
        
        return $resultPage;
    }
}